==> interweave-2.0.0.tgz: package/src/types.js <==
/**
 * @copyright   2016, Miles Johnson
 * @license     https://opensource.org/licenses/MIT
 * @flow
 */

/* eslint-disable no-undef */

import React from 'react';
import Filter from './Filter';
import Matcher from './Matcher';

export interface NodeInterface {
  attributes?: NamedNodeMap,
  childNodes: NodeList<Node>,
  nodeType: number,
  nodeName: string,
  textContent: string,
}

export type NodeConfig = {
  tagName?: string,
  rule: number,
  type: string,
  inline: boolean,
  block: boolean,
  self: boolean,
  void: boolean,
  parent: string[],
  children: string[],
};

export type PrimitiveType = string | number | boolean;

export type Attributes = { [key: string]: PrimitiveType };

export type FilterStructure = {
  filter: Filter,
  priority: number,
};

export type FilterList = FilterStructure[];

export type MatcherStructure = {
  matcher: Matcher<*>,
  priority: number,
};

export type MatcherList = MatcherStructure[];

export type MatcherFactory = (match: string, props: Object) => React.Element<*>;

export type MatchResponse = {
  match: string,
  shortName?: string,
  unicode?: string,
  [key: string]: any
};

export type ParserProps = {
  noHtml?: boolean,
  disableLineBreaks?: boolean,
  [key: string]: any,
};

export type ParsedNodes = Array<string | React.Element<*>>;

// Component Props

export type InterweaveProps = {
  content: string,
  disableFilters: boolean,
  disableMatchers: boolean,
  disableLineBreaks: boolean,
  emptyContent: ?React.Element<*>,
  filters: Filter[],
  matchers: Matcher<*>[],
  noHtml: boolean,
  onBeforeParse: (content: string) => string,
  onAfterParse: (content: ParsedNodes) => ParsedNodes,
  tagName: string,
};

export type MarkupProps = {
  content: string,
  emptyContent: ?React.Element<*>,
  disableLineBreaks: boolean,
  tagName: string,
  noHtml: boolean,
};

export type LinkProps = {
  href: string,
  children?: any,
  onClick?: () => void,
  newWindow?: boolean,
};

export type ElementProps = {
  attributes?: Attributes,
  className?: string,
  children?: any,
  tagName: string,
  selfClose?: boolean,
};

export type EmailProps = {
  children: string,
  emailParts: {
    username: string,
    host: string,
  },
};

export type HashtagProps = {
  children: string,
  hashtagName: string,
  hashtagUrl?: string,
  encodeHashtag?: boolean,
  preserveHash?: boolean,
};

export type UrlProps = {
  children: string,
  urlParts: {
    scheme: string,
    auth: string,
    host: string,
    port: string | number,
    path: string,
    query: string,
    fragment: string,
  },
};

export type EmojiProps = {
  shortName: string,
  unicode: string,
  emojiPath?: string,
  enlargeEmoji?: boolean,
};

export type EmojiOptions = {
  convertShortName: boolean;
  convertUnicode: boolean;
  renderUnicode: boolean;
};

==> interweave-3.0.1.tgz: package/src/types.js <==
/**
 * @copyright   2016, Miles Johnson
 * @license     https://opensource.org/licenses/MIT
 * @flow
 */

/* eslint-disable no-undef */

import React from 'react';
import Filter from './Filter';
import Matcher from './Matcher';

export interface NodeInterface {
  attributes?: NamedNodeMap,
  childNodes: NodeList<Node>,
  nodeName: string,
  nodeType: number,
  textContent: string,
}

export type NodeConfig = {
  block?: boolean,
  children?: string[],
  inline?: boolean,
  parent?: string[],
  rule?: number,
  self?: boolean,
  tagName?: string,
  type?: string,
  void?: boolean,
};

export type PrimitiveType = string | number | boolean;

export type Attributes = { [key: string]: PrimitiveType };

export type MatcherFactory = (match: string, props: Object) => React.Element<*>;

export type MatchResponse = {
  match: string,
  shortName?: string,
  unicode?: string,
  [key: string]: mixed,
};

export type ParserProps = {
  disableLineBreaks?: boolean,
  noHtml?: boolean,
  [key: string]: mixed,
};

export type ParsedNodes = Array<string | React.Element<*>>;

export type AfterParseCallback = (content: ParsedNodes) => ParsedNodes;

export type BeforeParseCallback = (content: string) => string;

// Component Props

export type InterweaveProps = {
  content: string,
  disableFilters: boolean,
  disableLineBreaks: boolean,
  disableMatchers: boolean,
  disableWhitelist: boolean,
  emptyContent: ?React.Element<*>,
  filters: Filter[],
  matchers: Matcher<*>[],
  noHtml: boolean,
  onAfterParse: AfterParseCallback,
  onBeforeParse: BeforeParseCallback,
  tagName: string,
};

export type MarkupProps = {
  content: string,
  disableLineBreaks: boolean,
  disableWhitelist: boolean,
  emptyContent: ?React.Element<*>,
  noHtml: boolean,
  tagName: string,
};

export type LinkProps = {
  children?: mixed,
  href: string,
  newWindow?: boolean,
  onClick?: () => void,
};

export type ElementProps = {
  attributes?: Attributes,
  children?: mixed,
  className?: string,
  selfClose?: boolean,
  tagName: string,
};

export type EmailProps = {
  children: string,
  emailParts: {
    host: string,
    username: string,
  },
};

export type HashtagProps = {
  children: string,
  encodeHashtag?: boolean,
  hashtagName: string,
  hashtagUrl?: string,
  preserveHash?: boolean,
};

export type UrlProps = {
  children: string,
  urlParts: {
    auth: string,
    fragment: string,
    host: string,
    path: string,
    port: string | number,
    query: string,
    scheme: string,
  },
};

export type EmojiProps = {
  emojiPath?: string,
  enlargeEmoji?: boolean,
  shortName: string,
  unicode: string,
};

export type EmojiOptions = {
  convertShortName: boolean,
  convertUnicode: boolean,
  renderUnicode: boolean,
};
